==> llm-docs-0.1.4.tgz: package/docs/components/bfrfp/index.md <==
---
title: BFRFP
description: Documentation for BFRFP
id: components-bfrfp
---

# LLM Platform RFP Processing (BFRFP)

## Important URLs

### Development URLs
- **Local Development Server:** `http://localhost:3004`
  - Start with `npm run dev`
  - Check `.env` file for actual port configuration
- **API Documentation:** `http://localhost:3004/api-docs`
  - Swagger/OpenAPI documentation when server is running
- **Health Check:** `http://localhost:3004/health`
  - Endpoint to verify RFP processor status
- **Processing Dashboard:** `http://localhost:3004/dashboard`
  - Real-time RFP processing status and metrics

### Repository & CI/CD
- **Repository:** `https://gitlab.com/bluefly-llm/BFRFP`
  - Main development branch: `main`
  - Release branch: `release`
- **CI/CD Pipeline:** `https://gitlab.com/bluefly-llm/BFRFP/-/pipelines`
- **Package Registry:** `https://gitlab.com/bluefly-llm/BFRFP/container_registry`

### Documentation
- **Project Documentation (Local):** `http://localhost:8080/docs/components/bfrfp/`
  - Requires BFDOCS to be running (`cd ../BFDOCS && npm run docs:serve`)
- **API Reference:** Available at `/docs` endpoint when server is running
- **Technical Documentation:** Located in `/docs` folder in repository
  - Architecture diagrams
  - RFP processing workflows
  - API specifications
  - Development guides

### Related Services
- **BFAPI Integration:** `http://localhost:3001` (Main API)
- **llm-mcp Integration:** `http://localhost:3002` (Model Control Plane)
- **llm-ui Connection:** `http://localhost:3000` (Frontend that consumes RFP services)
- **Document Processing:** `http://localhost:3004/processor`
- **Template Management:** `http://localhost:3004/templates`

### Environment-Specific URLs
- **Development:** `https://dev-rfp.bluefly.ai`
- **Staging:** `https://staging-rfp.bluefly.ai`
- **Production:** `https://rfp.bluefly.ai`

### Processing Endpoints
- **RFP Upload:** `http://localhost:3004/v1/rfp/upload`
- **RFP Analysis:** `http://localhost:3004/v1/rfp/analyze`
- **Response Generation:** `http://localhost:3004/v1/rfp/generate`
- **Template Management:** `http://localhost:3004/v1/templates`
- **Batch Processing:** `http://localhost:3004/v1/rfp/batch`

## Quick Start
```bash
# Clone repository
git clone https://gitlab.com/bluefly-llm/BFRFP.git

# Install dependencies
npm install

# Set up environment
cp .env.example .env

# Start development server
npm run dev
```

For detailed setup instructions, see [Setup Guide](setup).

## RFP Processing
For information on RFP processing workflows and customization, see [Processing Guide](processing).

## Overview

BFRFP is a specialized application for automating and enhancing the RFP (Request for Proposal) response process.

## Getting Started

- [Installation](./getting-started/installation)
- [Configuration](./getting-started/configuration)
- [User Guide](./user/USER_GUIDE)

## API Reference

- [API Documentation](./api/API)

## Technical Documentation

- [AI Integration](./technical/AI_INTEGRATION)

## Quick Links

- [API Reference](./api/README)
- [Technical Documentation](./technical/README)
- [User Guide](./user-guide/README)

## Development

For development guidelines and contribution information, see the [Development Guide](../development/setup).

==> llm-docs-1.0.1.tgz: package/docs/components/bfrfp/index.md <==
---
title: BFRFP
description: Documentation for BFRFP
id: components-bfrfp
---

# Bluefly RFP Processing (BFRFP)

## Important URLs

### Development URLs
- **Local Development Server:** `http://localhost:3004`
  - Start with `npm run dev`
  - Check `.env` file for actual port configuration
- **API Documentation:** `http://localhost:3004/api-docs`
  - Swagger/OpenAPI documentation when server is running
- **Health Check:** `http://localhost:3004/health`
  - Endpoint to verify RFP processor status
- **Processing Dashboard:** `http://localhost:3004/dashboard`
  - Real-time RFP processing status and metrics

### Repository & CI/CD
- **Repository:** `https://gitlab.com/bluefly-llm/BFRFP`
  - Main development branch: `main`
  - Release branch: `release`
- **CI/CD Pipeline:** `https://gitlab.com/bluefly-llm/BFRFP/-/pipelines`
- **Package Registry:** `https://gitlab.com/bluefly-llm/BFRFP/container_registry`

### Documentation
- **Project Documentation (Local):** `http://localhost:8080/docs/components/bfrfp/`
  - Requires BFDOCS to be running (`cd ../BFDOCS && npm run docs:serve`)
- **API Reference:** Available at `/docs` endpoint when server is running
- **Technical Documentation:** Located in `/docs` folder in repository
  - Architecture diagrams
  - RFP processing workflows
  - API specifications
  - Development guides

### Related Services
- **BFAPI Integration:** `http://localhost:3001` (Main API)
- **BFMCP Integration:** `http://localhost:3002` (Model Control Plane)
- **BFUI Connection:** `http://localhost:3000` (Frontend that consumes RFP services)
- **Document Processing:** `http://localhost:3004/processor`
- **Template Management:** `http://localhost:3004/templates`

### Environment-Specific URLs
- **Development:** `https://dev-rfp.bluefly.ai`
- **Staging:** `https://staging-rfp.bluefly.ai`
- **Production:** `https://rfp.bluefly.ai`

### Processing Endpoints
- **RFP Upload:** `http://localhost:3004/v1/rfp/upload`
- **RFP Analysis:** `http://localhost:3004/v1/rfp/analyze`
- **Response Generation:** `http://localhost:3004/v1/rfp/generate`
- **Template Management:** `http://localhost:3004/v1/templates`
- **Batch Processing:** `http://localhost:3004/v1/rfp/batch`

## Quick Start
```bash
# Clone repository
git clone https://gitlab.com/bluefly-llm/BFRFP.git

# Install dependencies
npm install

# Set up environment
cp .env.example .env

# Start development server
npm run dev
```

For detailed setup instructions, see [Setup Guide](setup).

## RFP Processing
For information on RFP processing workflows and customization, see [Processing Guide](processing).

## Overview

BFRFP is a specialized application for automating and enhancing the RFP (Request for Proposal) response process.

## Getting Started

- [Installation](./getting-started/installation)
- [Configuration](./getting-started/configuration)
- [User Guide](./user/USER_GUIDE)

## API Reference

- [API Documentation](./api/API)

## Technical Documentation

- [AI Integration](./technical/AI_INTEGRATION)

## Quick Links

- [API Reference](./api/README)
- [Technical Documentation](./technical/README)
- [User Guide](./user-guide/README)

## Development

For development guidelines and contribution information, see the [Development Guide](../development/setup).
